package de.intevation.flys.artifacts.transitions;

import de.intevation.flys.artifacts.states.State;

/**
 * The default implementation of a <code>Transition</code>.
 *
 * @author <a href="mailto:ingo.weinzierl@intevation.de">Ingo Weinzierl</a>
 */
public class DefaultTransition implements Transition {

    /** The ID of the current state */
    protected String from;

    /** The ID of the target state */
    protected String to;


    /**
     * The default constructor.
     */
    public DefaultTransition() {
    }


    /**
     * The default constructor.
     *
     * @param from The current state.
     * @param to The target state.
     */
    public DefaultTransition(String from, String to) {
        this.from = from;
        this.to   = to;
    }


    /**
     * Returns the current state ID.
     *
     * @return the current state ID.
     */
    public String getFrom() {
        return from;
    }


    /**
     * Returns the target state ID.
     *
     * @return the target state ID.
     */
    public String getTo() {
        return to;
    }


    /**
     * Set the current state ID.
     *
     * @param to the current state ID.
     */
    public void setFrom(String from) {
        this.from = from;
    }


    /**
     * Set the target state ID.
     *
     * @param to the target state ID.
     */
    public void setTo(String to) {
        this.to = to;
    }


    /**
     * This method always returns <i>true</i>.
     *
     * @param state The target state.
     *
     * @return true.
     */
    public boolean isValid(State state) {
        return true;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
